 /*****************************************************************************
 *   Copyright (C) 2004 by Michael Schulze                                    *
 *   mike.s@genion.de                                                         *
 *                                                                            *
 *  The code contained in this file is free software; you can redistribute    *
 *  it and/or modify it under the terms of the GNU Lesser General Public      *
 *  License as published by the Free Software Foundation; either version      *
 *  2.1 of the License, or (at your option) any later version.                *
 *                                                                            *
 *  This file is distributed in the hope that it will be useful,              *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU         *
 *  Lesser General Public License for more details.                           *
 *                                                                            *
 *  You should have received a copy of the GNU Lesser General Public          *
 *  License along with this code; if not, write to the Free Software          *
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA *
 *                                                                            *
 *  iTunes and iPod are trademarks of Apple                                   *
 *                                                                            *
 *  This product is not supported/written/published by Apple!                 *
 *****************************************************************************/

#ifndef ITUNESDBITUNESDBDATASOURCE_H
#define ITUNESDBITUNESDBDATASOURCE_H

#include "track.h"
#include "playlist.h"
#include "playlistitem.h"

namespace itunesdb {

/**
 * ItunesDBDataSource is the interface that delivers data to an iTunesDBWriter
 * @author Michael Schulze
*/
class ItunesDBDataSource {
public:

    virtual ~ItunesDBDataSource() {}

    /**
     * called when the ItunesDBWriter starts to write
     */
    virtual void writeInit() = 0;

    /**
     * called when the ItunesDBWriter is done writing the database
     */
    virtual void writeFinished() = 0;

    /**
     * returns the number of playlists that need to be written
     */
    virtual Q_UINT32 getNumPlaylists() = 0;

    /**
     * returns the number of tracks that need to be written
     */
    virtual Q_UINT32 getNumTracks() = 0;

    /**
     * Returns a list with all the tracks
     */
    virtual TrackPtrList& getTrackList() = 0;

    /**
     * returns the first playlist and sets the playlist position for nextPlaylist() to the first
     * playlist
     * 
     */
    virtual Playlist * firstPlaylist() = 0;

    /**
     * returns the next playlist (see firstPlaylist())
     */
    virtual Playlist * nextPlaylist() = 0;

    /**
     * gets called if an error occured during the write process.
     * The write process ends after a call to this method.
     */
    virtual void handleError( const QString& message) = 0;

    /**
     * Returns the title of the master Playlist (thus the title of the iPod)
     */
    virtual const QString& getTitle() = 0;
};

}

#endif
